==> OpenID-1.2.1.tar.gz: OpenID/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'OpenID-module';
$lang['postinstall'] = 'OpenID-modulen har installerats';
$lang['postuninstall'] = 'OpenID-modulen har avinstallerats';
$lang['really_uninstall'] = '&Auml;r du s&auml;ker p&aring; att du vill avinstallera modulen OpenID';
$lang['uninstalled'] = 'Modulen har avinstallerats.';
$lang['installed'] = 'Modul version %s installerad.';
$lang['upgraded'] = 'Modulen uppgraderad till version %s.';
$lang['moddescription'] = 'Denna modul ger m&ouml;jlighet att anv&auml;nda OpenID som inloggningsmetod till CMS Made Simple och FrontEndUsers-modulen.';
$lang['changelog'] = '<ul>
<li>Version 1.0.0 First public release with support for OpenID and Facebook authentication</li>
<li>Version 1.1.0 Added support for Twitter authentication. Possible to configure redirects after login. Added OpenID Selector as additional OpenID login page style.
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The OpenID module provides functionality to add an OpenID or Facebook account to a registered frontend user. That user can then log in using that identity instead of the ordinary frontend account.</p>
<h3>How Do I Use It</h3>
<p><ol>
    <li>Make sure that FrontEndUsers is installed</li>
    <li>Install the OpenID module</li>
    <li>Check out the settings page if you want to use Facebook as a provider</li>
    <li>Add the tag <i>{OpenID}</i> to a new or an existing page</li>
    <li>Log in as an already registered frontend user</li>
    <li>Visit the page with the OpenID tag and register a provider</li>
    <li>Logout</li>
    <li>Revisit the page with the OpenID tag, select the same provider you just registered, authenticate and behold: You are now logged in</li>
</ol></p>
<h3>Support</h3>
<p>Getting OpenID to work properly can be a bit of a struggle if you are not
fortunate enough to have an environment that already has all the bits and pieces in place.
<br/>Some places to check before asking for help:<br/>
<ul>
    <li>The janrain README file in the /modules/OpenID/openid-php-openid-*version* directory</li>
    <li>Run the detect.php file in /modules/OpenID/openid-php-openid-*version*/examples/</li>
    <li>Try different OpenID providers in order to determine if all are broken or just some.
    A rule of thumb is that Facebook is a separate thing compared to the OpenID providers.
    Providers that use discovery (like Google) is different from the simpler ones like myOpenID</li>
    <li>Check your php error logs for any exceptions or error messages. Google any output for clues about how to solve them</li>
    <li>Set openid.debug to true in your config.php. This will output a ton of messages to the php error log</li>
</ul>
</p>
<h3>Credits</h3>
<p>The OpenID library is standing on the shoulders of giants, namely:
<ul>
    <li><a href="http://github.com/openid/php-openid/" target="_blank">PHP OpenID library by JanRain, Inc.</a></li>
    <li><a href="http://jvance.com/pages/JQueryOpenIDPlugin.xhtml" target="_blank">OpenID jQuery plugin by Jarret Vance</a></li>
    <li><a href="https://github.com/facebook/php-sdk/" target="_blank">Facebook PHP SDK</a></li>
    <li><a href="http://www.jquery.com" target="_blank">jQuery</a></li>
</ul>
</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2010, <a href="mailto:openid@lennartssons.net">Henrik Lennartsson</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.apache.org/licenses/LICENSE-2.0.html">Apache License Version 2.0</a>. You must agree to this license before using the module.</p>
';
$lang['openid_providers'] = 'Aktiva leverant&ouml;rer';
$lang['settings'] = 'Inst&auml;llningar';
$lang['users'] = 'Anv&auml;ndare';
$lang['submit'] = 'Skicka';
$lang['cancel'] = 'Avbryt';
$lang['openid_fail'] = 'Din identitet &auml;r %s men inloggningen misslyckades';
$lang['openid_success'] = 'Din identitet &auml;r %s och du har blivit inloggad som anv&auml;ndare %s';
$lang['openid_unknown'] = 'Din identitet &auml;r %s men &auml;r inte registrerad till n&aring;gon anv&auml;ndare.';
$lang['openid_redirecting'] = 'V&auml;nta, du skickas nu vidare till din OpenID-leverant&ouml;r';
$lang['openid_added_identity'] = 'Lade till %s identitet %s';
$lang['openid_remove_identity_success'] = 'Tog bort identiteten';
$lang['openid_remove_identity_failed'] = 'Det gick inte att ta bort identiten';
$lang['list_registered_providers'] = 'Registrerade identiteter';
$lang['list_information'] = 'F&ouml;ljande OpenID-leverant&ouml;rer har associerats med ditt anv&auml;ndarkonto. Du kan anv&auml;nda vilket som helst av dessa f&ouml;r att logga in';
$lang['list_link_remove'] = 'Tag bort';
$lang['list_add'] = 'L&auml;gg till eller uppdatera identitet';
$lang['list_add_information'] = 'V&auml;lj en leverant&ouml;r och slutf&ouml;r inloggningen. Om inloggningen lyckas kommer din identitet l&auml;ggas till i listan med dina registrerade identiteter. Om du redan har en identitet fr&aring;n samma leverant&ouml;r kommer den att ers&auml;ttas.';
$lang['login_enter_your'] = 'Ange din';
$lang['login_provider_user_name'] = 'Anv&auml;ndarnamn';
$lang['login_openid'] = 'OpenID ';
$lang['login_login'] = 'Inloggning';
$lang['login_signin'] = 'Logga in';
$lang['login_click_provider'] = 'V&auml;lj din OpenID-leverant&ouml;r';
$lang['login_openid_information'] = 'OpenID &auml;r en standard som g&ouml;r att du kan logga in p&aring; flera olika webbplatser med samma anv&auml;ndaruppgifter.
 L&auml;s mer om OpenID <a href="http://openid.net/what/">h&auml;r</a> och hur du <a href="http://openid.net/get">skaffar ett eget OpenID-konto</a>';
$lang['register_provider'] = 'Registrera en OpenID-leverant&ouml;r';
$lang['register_information'] = 'V&auml;lj en leverant&ouml;r och slutf&ouml;r inloggningen. N&auml;r den &auml;r avslutad kommer ditt anv&auml;ndarkonto att associeras med din OpenID-identitet. Detta g&ouml;r att du kan logga in med ditt OpenID-konto ist&auml;llet f&ouml;r ditt vanliga anv&auml;ndarnamn och l&ouml;senord.';
$lang['twitter_failed_or_canceled'] = 'Twitter-inloggning avbr&ouml;ts eller misslyckades av annan anledning';
$lang['facebook_failed_or_canceled'] = 'Facebook-inloggning avbr&ouml;ts eller misslyckades av annan anledning';
$lang['qca'] = 'P0-433441576-1278020048966';
$lang['utmz'] = '156861353.1301786602.18.11.utmcsr=cmsms.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utma'] = '156861353.1727400508.1284156629.1301771692.1301786602.18';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.4.9.1301786612894';
?>

==> OpenID-1.3.0.tar.gz: OpenID/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'OpenID-module';
$lang['postinstall'] = 'OpenID-modulen har installerats';
$lang['postuninstall'] = 'OpenID-modulen har avinstallerats';
$lang['really_uninstall'] = '&Auml;r du s&auml;ker p&aring; att du vill avinstallera modulen OpenID';
$lang['uninstalled'] = 'Modulen har avinstallerats.';
$lang['installed'] = 'Modul version %s installerad.';
$lang['upgraded'] = 'Modulen uppgraderad till version %s.';
$lang['moddescription'] = 'Denna modul ger m&ouml;jlighet att anv&auml;nda OpenID som inloggningsmetod till CMS Made Simple och FrontEndUsers-modulen.';
$lang['changelog'] = 'L&auml;s mer p&aring; projektets wiki <a href="https://bitbucket.org/henriklen/openid/wiki/">https://bitbucket.org/henriklen/openid/wiki/</a>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The OpenID module provides functionality to add an OpenID or Facebook account to a registered frontend user. That user can then log in using that identity instead of the ordinary frontend account.</p>
<h3>How Do I Use It</h3>
<p><ol>
    <li>Make sure that FrontEndUsers is installed</li>
    <li>Install the OpenID module</li>
    <li>Check out the settings page if you want to use Facebook as a provider</li>
    <li>Add the tag <i>{OpenID}</i> to a new or an existing page</li>
    <li>Log in as an already registered frontend user</li>
    <li>Visit the page with the OpenID tag and register a provider</li>
    <li>Logout</li>
    <li>Revisit the page with the OpenID tag, select the same provider you just registered, authenticate and behold: You are now logged in</li>
</ol></p>
<h3>Support</h3>
<p>Check out the wiki for FAQ and additional information: <a href="https://bitbucket.org/henriklen/openid/wiki/">https://bitbucket.org/henriklen/openid/wiki/</a><p>
<p>Getting OpenID to work properly can be a bit of a struggle if you are not
fortunate enough to have an environment that already has all the bits and pieces in place.
<br/>Some places to check before asking for help:<br/>
<ul>
    <li>The janrain README file in the /modules/OpenID/openid-php-openid-*version* directory</li>
    <li>Run the detect.php file in /modules/OpenID/openid-php-openid-*version*/examples/</li>
    <li>Try different OpenID providers in order to determine if all are broken or just some.
    A rule of thumb is that Facebook is a separate thing compared to the OpenID providers.
    Providers that use discovery (like Google) is different from the simpler ones like myOpenID</li>
    <li>Check your php error logs for any exceptions or error messages. Google any output for clues about how to solve them</li>
    <li>Set openid.debug to true in your config.php. This will output a ton of messages to the php error log</li>
</ul>
</p>
<h3>Credits</h3>
<p>The OpenID library is standing on the shoulders of giants, namely:
<ul>
    <li><a href="http://github.com/openid/php-openid/" target="_blank">PHP OpenID library by JanRain, Inc.</a></li>
    <li><a href="http://jvance.com/pages/JQueryOpenIDPlugin.xhtml" target="_blank">OpenID jQuery plugin by Jarret Vance</a></li>
    <li><a href="https://github.com/facebook/facebook-php-sdk" target="_blank">Facebook PHP SDK</a></li>
    <li><a href="http://www.jquery.com" target="_blank">jQuery</a></li>
</ul>
</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2010-2012, <a href="mailto:openid@lennartssons.net">Henrik Lennartsson</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.apache.org/licenses/LICENSE-2.0.html">Apache License Version 2.0</a>. You must agree to this license before using the module.</p>';
$lang['openid_providers'] = 'Aktiva leverant&ouml;rer';
$lang['settings'] = 'Inst&auml;llningar';
$lang['users'] = 'Anv&auml;ndare';
$lang['submit'] = 'Skicka';
$lang['cancel'] = 'Avbryt';
$lang['openid_fail'] = 'Din identitet &auml;r %s men inloggningen misslyckades';
$lang['openid_success'] = 'Din identitet &auml;r %s och du har blivit inloggad som anv&auml;ndare %s';
$lang['openid_unknown'] = 'Din identitet &auml;r %s men &auml;r inte registrerad till n&aring;gon anv&auml;ndare.';
$lang['openid_redirecting'] = 'V&auml;nta, du skickas nu vidare till din OpenID-leverant&ouml;r';
$lang['openid_added_identity'] = 'Lade till %s identitet %s';
$lang['openid_remove_identity_success'] = 'Tog bort identiteten';
$lang['openid_remove_identity_failed'] = 'Det gick inte att ta bort identiten';
$lang['list_registered_providers'] = 'Registrerade identiteter';
$lang['list_information'] = 'F&ouml;ljande OpenID-leverant&ouml;rer har associerats med ditt anv&auml;ndarkonto. Du kan anv&auml;nda vilket som helst av dessa f&ouml;r att logga in';
$lang['list_link_remove'] = 'Tag bort';
$lang['list_add'] = 'L&auml;gg till eller uppdatera identitet';
$lang['list_add_information'] = 'V&auml;lj en leverant&ouml;r och slutf&ouml;r inloggningen. Om inloggningen lyckas kommer din identitet l&auml;ggas till i listan med dina registrerade identiteter. Om du redan har en identitet fr&aring;n samma leverant&ouml;r kommer den att ers&auml;ttas.';
$lang['login_enter_your'] = 'Ange din';
$lang['login_provider_user_name'] = 'Anv&auml;ndarnamn';
$lang['login_openid'] = 'OpenID ';
$lang['login_login'] = 'Inloggning';
$lang['login_signin'] = 'Logga in';
$lang['login_click_provider'] = 'V&auml;lj din OpenID-leverant&ouml;r';
$lang['login_openid_information'] = 'OpenID &auml;r en standard som g&ouml;r att du kan logga in p&aring; flera olika webbplatser med samma anv&auml;ndaruppgifter.
 L&auml;s mer om OpenID <a href="http://openid.net/what/">h&auml;r</a> och hur du <a href="http://openid.net/get">skaffar ett eget OpenID-konto</a>';
$lang['register_provider'] = 'Registrera en OpenID-leverant&ouml;r';
$lang['register_information'] = 'V&auml;lj en leverant&ouml;r och slutf&ouml;r inloggningen. N&auml;r den &auml;r avslutad kommer ditt anv&auml;ndarkonto att associeras med din OpenID-identitet. Detta g&ouml;r att du kan logga in med ditt OpenID-konto ist&auml;llet f&ouml;r ditt vanliga anv&auml;ndarnamn och l&ouml;senord.';
$lang['twitter_failed_or_canceled'] = 'Twitter-inloggning avbr&ouml;ts eller misslyckades av annan anledning';
$lang['facebook_failed_or_canceled'] = 'Facebook-inloggning avbr&ouml;ts eller misslyckades av annan anledning';
$lang['utmz'] = '156861353.1343313370.1.1.utmccn=(organic)|utmcsr=google|utmctr=|utmcmd=organic';
$lang['utma'] = '156861353.2131917110.1343313370.1343313370.1343316201.2';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
